@echo off

setlocal

@rem ----------------------------------------------------------------------
@rem  findJava.bat -- try to find the path to a java interpreter
@rem
@rem  stdout:     echoes java command path or ERROR to standard output
@rem  console:    echoes error message (if any) to console
@rem  errorlevel: returns 0 if java found, 1 if not found
@rem
@rem  (C) Copyright IBM Corp. 2005 All Rights Reserved.
@rem
@rem  US Government Users Restricted Rights - Use, duplication or
@rem  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@rem ----------------------------------------------------------------------

@rem :
@rem : Determine where this script is installed
@rem :

set THIS_CMD_PATH=%~f0

set THIS_CMD_DIR=%THIS_CMD_PATH:\findJava.bat=%


@rem :
@rem : See if the user has set JAVAHOME
@rem :

if not "%JAVAHOME%" == "" (
    if exist "%JAVAHOME%\bin\java.exe" (
        set JAVACMD=%JAVAHOME%\bin\java.exe
        goto foundJava
    )
)


@rem :
@rem : If current dir ends in 'bin', we're on an endpoint
@rem :

set CMD_DIR_PARENT=%THIS_CMD_DIR:\bin=%

if not "%THIS_CMD_DIR%" == "%CMD_DIR_PARENT%\bin" goto endEndpoint

  @rem : Look in jre142

  set MA_JRE142_JAVA=%CMD_DIR_PARENT%\jre142\jre\bin\java.exe

  if exist "%MA_JRE142_JAVA%" set JAVACMD=%MA_JRE142_JAVA%
  if exist "%MA_JRE142_JAVA%" goto foundJava

  @rem : Look in jre131

  set MA_JRE131_JAVA=%CMD_DIR_PARENT%\jre131\jre\bin\java.exe

  if exist "%MA_JRE131_JAVA%" set JAVACMD=%MA_JRE131_JAVA%
  if exist "%MA_JRE131_JAVA%" goto foundJava
  
  goto notFound

:endEndpoint


@rem :
@rem : If current dir ends in 'scripts' and 'isCluster.bat'
@rem : exists, we're on a cluster MS.  Warn the user if JAVAHOME
@rem : wasn't set
@rem :

set CMD_DIR_PARENT=%THIS_CMD_DIR:\scripts=%

if not "%THIS_CMD_DIR%" == "%CMD_DIR_PARENT%\scripts" goto endClusterMS

if not exist "%THIS_CMD_DIR%\isCluster.bat" goto endClusterMS

  if "%JAVAHOME%" == "" @echo Current environment is a management server cluster. > con
  if "%JAVAHOME%" == "" @echo Please set environment variable JAVAHOME.           > con
  if "%JAVAHOME%" == "" goto notFound
  
  set CLUSTER_JAVA=%JAVAHOME%\bin\java.exe
  
  if exist "%CLUSTER_JAVA%" set JAVACMD=%CLUSTER_JAVA%
  if exist "%CLUSTER_JAVA%" goto foundJava
  
  goto notFound
  
:endClusterMS


@rem :
@rem : If current dir ends in 'scripts', we're on a standalone MS
@rem :

set CMD_DIR_PARENT=%THIS_CMD_DIR:\scripts=%

if not "%THIS_CMD_DIR%" == "%CMD_DIR_PARENT%\scripts" goto endStandaloneMS

  @rem : Look in _uninst

  set MS_UNINST_JAVA=%CMD_DIR_PARENT%\_uninst\_jvm\bin\java.exe

  if exist "%MS_UNINST_JAVA%" set JAVACMD=%MS_UNINST_JAVA%
  if exist "%MS_UNINST_JAVA%" goto foundJava

  @rem : Look in _uninst53

  set MS_UNINST_JAVA=%CMD_DIR_PARENT%\_uninst53\_jvm\bin\java.exe

  if exist "%MS_UNINST_JAVA%" set JAVACMD=%MS_UNINST_JAVA%
  if exist "%MS_UNINST_JAVA%" goto foundJava
  
  goto notFound

:endStandaloneMS


@rem :
@rem : Give up if we aren't in a normal location
@rem :

@echo Cannot determine path to java command. Current location does not > con
@echo appear to be an valid ITCAM management server or endpoint.       > con
goto notfound

:endBadInstall


@rem :
@rem : Couldn't find java. Echo "ERROR" to stdout, an error message to console
@rem : and return a failure code
@rem :

:notfound

@echo Cannot find path to java executable > con
@echo ERROR
endlocal
exit /B 1


@rem :
@rem : We found it, echo the location to stdout and return a success code
@rem :

:foundJava

@echo %JAVACMD%
endlocal
exit /B 0


@rem ----------------------------------------------------------------------
@rem End script
@rem ----------------------------------------------------------------------
