# ----------------------------------------------------------------------
#  findJava.sh -- try to find the path to a java interpreter
#
#  output:  echoes java path to standard output
# 
#  (C) Copyright IBM Corp. 2005 All Rights Reserved.
#  
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ----------------------------------------------------------------------

# Note: if-tests must use 'test' syntax instead of '['
#       in order to work under OS/400 qsh.


# Determine where this script is installed

case "$0" in
  /*)   THIS_CMD_PATH="$0"       ;;
   *)   THIS_CMD_PATH="`pwd`/$0" ;;
esac

THIS_CMD_DIR="`dirname $THIS_CMD_PATH`"
THIS_CMD_DIR=`(cd "$THIS_CMD_DIR" 2>/dev/null && pwd)`

CMD_DIR_PARENT=`(cd "$THIS_CMD_DIR/.." 2>/dev/null && pwd)`


# See if the user has set JAVAHOME

if test "$JAVAHOME" != "" ; then
  if test -x "$JAVAHOME/bin/java" ; then
      echo "$JAVAHOME/bin/java"
      exit 0
  fi
fi


# If current dir ends in 'scripts' and 'isCluster.sh' exists,
# we're on a clustered MS and we need users to specify variable
# JAVAHOME.

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/scripts" ; then
  if test -f "$THIS_CMD_DIR/isCluster.sh" ; then

    if test "$JAVAHOME" = "" ; then
      echo Current environment is a management server cluster. 1>&2
      echo Please set environment variable JAVAHOME.           1>&2
      exit 1
    fi
  
    if test -f "$JAVAHOME/bin/java" ; then
        echo "$JAVAHOME/bin/java"
        exit 0
    fi
  fi
fi


# Otherwise if current dir ends in 'scripts', we're on a
# standalone MS, and we should look in _uninst

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/scripts" ; then

  for jbin in "$CMD_DIR_PARENT/_uninst/_jvm/jre/bin"   \
              "$CMD_DIR_PARENT/_uninst/_jvm/bin"       \
              "$CMD_DIR_PARENT/_uninst53/_jvm/jre/bin" \
              "$CMD_DIR_PARENT/_uninst53/_jvm/bin"
  do
    if test -x "$jbin/java" ; then
      echo "$jbin/java"
      exit 0
    fi
  done
fi


# If we're on a z/OS MA, try setup script in /etc

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/bin" ; then
  if test "`uname`" = "OS/390" ; then
    if test -f "/etc/tmtp/MA/config/setupEnv.sh" ; then
       . "/etc/tmtp/MA/config/setupEnv.sh"
    fi
    if test -x "$JAVAHOME/bin/java" ; then
      echo "$JAVAHOME/bin/java"
      exit 0
    fi
  fi
fi


# If we're on an OS/400 MA, try setup script in /qibm

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/bin" ; then
  if test "`uname`" = "OS400" ; then
    if test -f "/qibm/userdata/tivoli/tmtp/ma/bin/setupEnv400.sh" ; then
      . "/qibm/userdata/tivoli/tmtp/ma/bin/setupEnv400.sh"
    fi
    if test -x "$JAVA_DIR/bin/java" ; then
      echo "$JAVA_DIR/bin/java"
      exit 0
    fi
  fi
fi


# If we're on an endpoint, try setup script in ./config

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/bin" ; then
  if test -f "$CMD_DIR_PARENT/config/setupEnv.sh" ; then
    . "$CMD_DIR_PARENT/config/setupEnv.sh"
  fi
  if test -x "$JAVAHOME/bin/java" ; then
    echo "$JAVAHOME/bin/java"
    exit 0
  fi
fi


# If we're on an endpoint, try setup script in ./bin

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/bin" ; then
  if test -f "$CMD_DIR_PARENT/bin/setupEnv.sh" ; then
    . "$CMD_DIR_PARENT/bin/setupEnv.sh"
  fi
  if test -x "$JAVAHOME/bin/java" ; then
    echo "$JAVAHOME/bin/java"
    exit 0
  fi
fi


# If we're on an endpoint, check jre subdirs

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/bin" ; then

  for jbin in "$CMD_DIR_PARENT/jre131/bin"     \
              "$CMD_DIR_PARENT/jre131/jre/bin" \
              "$CMD_DIR_PARENT/jre142/bin"     \
              "$CMD_DIR_PARENT/jre142/jre/bin"
  do
    if test -x "$jbin/java" ; then
      echo "$jbin/java"
      exit 0
    fi
  done
fi


# OK, give up...

echo Cannot find path to java executable 1>&2
exit 1

# ----------------------------------------------------------------------
# End script
# ----------------------------------------------------------------------
