#!/bin/sh
#########################################################
#OCO Source Materials
#
#Licensed Materials - Property of IBM
#
#5724-C02
#
#(C) Copyright IBM Corp. 2003 - 2006  All Rights Reserved.
#
#US Government Users Restricted Rights - Use, duplication or
#disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#########################################################
#
# File: start_tmtpd.sh
# Assumes following environment variables have been set.
# INTERP, BASEDIR, JAVAHOME, and MA_USER
#

# Uncomment following line if to send  extra parameters to JVM
# JVM Maximum Heap Size
# EXTRA_JVM_PARAMS="-Xmx256m"

#Export DEBUG_TMTP to any value to debug events on the script.
if [ "${DEBUG_TMTP}" != "" ]; then
	set -x
fi

#*** Define all functions
#*
Version() {
    # Return 1 for kernels 2.4.0 thru 2.4.9 on Intel x86
    Arch=`uname -m | sed -e 's/^i./i3/'`
    if [ "$Arch" = "i386" ]; then
        Pattern=`uname -r`
        Kernel=`echo $Pattern | sed -e 's/^2\.4\..*/2.4./'`
        if [ "$Kernel" = "2.4." ]; then
            Release=`echo $Pattern | sed -e 's/^2\.4\.\([0-9]*\).*/\1/'`
            if [ "$Release" -lt 10 ]; then
                return 1
            fi
        fi
        # IBM JRE 1.3.1 classic has known issues on RHEL 3.0
	# SR6 seems to have fixes.
        if [ -f /etc/redhat-release ]; then
            grep "Red Hat Enterprise Linux ES release 3" \
                /etc/redhat-release 2>&1 >/dev/null && return 1
        fi
        if [ -f /etc/redflag-release ]; then
            grep "Red Flag Linux Advanced Server" \
                /etc/redflag-release 2>&1 >/dev/null && return 1
        fi
    fi
    return 0
} # Version

# Remove the Shutdown flag file
RemoveSFF() {
  rm -f $SFF >/dev/null 2>/dev/null
} # RemoveSFF

# Create the Shutdown flag file
CreateSFF() {
  echo DONE >$SFF 2>/dev/null
  chmod 666 $SFF >/dev/null 2>/dev/null
} # CreateSFF


# Prepare the StdOut file for running the MA
PrepStdOut() {
  touch ${MASTDOUT} >/dev/null 2>/dev/null
  if [ $? -eq 0 ]; then
    chmod ugo+wr ${MASTDOUT} >/dev/null 2>/dev/null
  else
    MASTDOUT=/dev/null
  fi
} # PrepStdOut


# Prepare the StdErr file for running the MA
PrepStdErr() {
  touch ${MASTDERR} >/dev/null 2>/dev/null
  if [ $? -eq 0 ]; then
    chmod ugo+wr ${MASTDERR} >/dev/null 2>/dev/null
  else
    MASTDERR=/dev/null
  fi
} # PrepStdErr


# c@IY64264
# Get running status of the MA's JVM process
GetMARunningStatus() {
    if [ -f "${PIDFILE}" ] ; then
    	JVMPID=`cat ${PIDFILE}`
    	ps -p $JVMPID 2>/dev/null > /dev/null
        #Revert the logic of command result
    	if [ $? -eq 0 ]; then
            IS_RUNNING=1
    	else
       	    IS_RUNNING=0
    	fi
    else
        IS_RUNNING=0
    fi
    
    if [ $IS_RUNNING -eq 0 ]; then 
    	    #Returns a list of any procs with tapmagent in their listings
            #(should only be one)
            TAPMAGENTPID=`ps -ef | awk '/tapmagent/ && !/awk/ {print $2}'`
            #echo TAPMAGENTPID is $TAPMAGENTPID
            if [ "$TAPMAGENTPID" ]; then
                IS_RUNNING=1
            else
	        IS_RUNNING=0
            fi
    fi
    return $IS_RUNNING
}

#
# Monitor the JVMPID until is no longer in the process table or
# MAX_WAIT_TIME has been elapsed.
#
WaitForProcessToStop() {
    MAX_WAIT_TIME=180

    echo 'Please wait while TMTP Management Agent stops'

    i=0
    IS_RUNNING=1
    while [ $IS_RUNNING -eq 1 ]
    do
        i=`expr $i + 2`
        sleep 2
		if [ $i -ge $MAX_WAIT_TIME ]; then
			echo Warning.
			echo Verify that PID $JVMPID belongs to the TMTP Management Agent.
			echo Timeout of $MAX_WAIT_TIME secs. while waiting for PID: $JVMPID to stop.
			echo Standard stop method reached timeout stage. 
			echo Executing t1 stop method...
			# ack-IY85834
			${BIN_DIR}/t1 stopeng  
			sleep 5
			GetMARunningStatus
			if [ $IS_RUNNING -eq 1 ]; then
			    #t1 could not shut down either the JVM or tapmagent process
			    echo Could not shutdown the tapmagent process with PID $TAPMAGENTPID.
			    exit 1
			fi
		fi
		if [ $SHOW_PROGRESS -eq 1 ]; then
			case  "${INTERP}" in
				"aix4-r1"|"hpux11"|"solaris2") echo ".\c";;
				"zos") echo ".\\c";;
				*) echo -n ".";;
			esac
		fi
        GetMARunningStatus
    done
}
# end@IY64264

SHOW_PROGRESS=1


# PATH must include /usr/bin
PATH="$PATH":/usr/sbin:/usr/bin

# exec command default is exec, but may need to be nohup on some
# platforms, e.g. on hpux
EXEC_CMD=exec

# The INSTALL* values are replaced during install.
# Install should also set the JAVA_DIR value in setupEnv400.sh

BINDIR=`dirname $0`
. ${BINDIR}/setupEnv.sh

JAVADIR=jre/bin

# File to use for shutdown
SFF=${BASEDIR}/config/tmtpshutdown.flag

#This should preferably be on an unmountable file system
#Eg. export EXECUTE_DIR=/var
EXECUTE_DIR=/var
export EXECUTE_DIR

#Set daemon logging output. Set to ON to use syslog.
#Set to OFF to log to stderr.
#export LOGGING=OFF
LOGGING=ON
export LOGGING

TMX4J_HOME=$BASEDIR
export TMX4J_HOME

#Leave the following three variables unchanged unless you have modified
#the original install structure
LIB_DIR=${BASEDIR}/lib
BIN_DIR=${BASEDIR}/bin/${INTERP}
CONFIG_DIR=${BASEDIR}/config

# File to store the pid in
PIDFILE=${CONFIG_DIR}/eppid

# Default file specifications where stdout and stderr are redirected.
MASTDOUT=${BASEDIR}/ma-stdout.log
MASTDERR=${BASEDIR}/ma-stderr.log


# Umask reset for zOS to allow WebSphere to write to app directories
# umask 002 sets default to be u=rwx,g=rwx,o=rx
if [ "${INTERP}" = "zos" ]; then
    umask 002
fi

# Handle request from init.d for a start message
if [ "$1" = "start_msg" ]; then
    echo "Starting tmtpd"
    exit 0
fi

# Handle request from init.d for a stop message
if [ "$1" = "stop_msg" ]; then
    echo "Stopping tmtpd"
    exit 0
fi

#Agent shutdown support
if [ "$1" = "stop" ]; then
    # begin@IY64264 ADD handler to check if JVM running for a stop
    GetMARunningStatus
    if [ $? -eq 0 ]
    then
        echo 'TMTP MA is not running.'
    else
        # Create the shutdown flag file to cause MA to shutdown
        CreateSFF
        WaitForProcessToStop
        echo ""
        rm -f $PIDFILE
    fi
    exit 0
fi

# Handle an unrecognized request (assume "" or "start" means start) # oyh d129344 quick fix
#if [ "$1" -a ! \( "$1" = "start" -o  "$1" = "restart"  \) ]; then  # take out args check
    #echo "Unknown command ($1), no action performed"               # for support on Solaris
    #exit 0
#fi

# Agent start support

# This STARTTMTPD program will submit a job to run the start_tmtpd.sh as QTIVROOT
# and will also run in the QSYSWRK subsystem - the call to start_tmtpd.sh
# is called with the OS400 paramter so it will not execute this program call twice.
if [ "${INTERP}" = "OS400" ]; then
    if [ "$1" != "OS400" ]; then
        if [ "$1" != "stop" ]; then
            `system "CALL PGM(QTIVTMTP/STARTTMTPD)"`
            exit 0
        fi
    fi
fi



# Default to root user to run the MA as if no user specified
if [ "${MA_USER}" = "" ]; then
  MA_USER=root
  export MA_USER
fi

#The LD_LIBRARY_PATH must include the location of the libjmxerror.so
#and the libjvm.so files - you should be able to leave it as in the example
#Eg. export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${JAVA_HOME}/jre/lib/sparc/:
# depending on target platform, paths may be different

if [ "${INTERP}" = "solaris2" ]; then
  LD_LIBRARY_PATH=${JAVAHOME}/lib/sparc/hotspot:${JAVAHOME}/lib/sparc:${BIN_DIR}:${LD_LIBRARY_PATH}
  export LD_LIBRARY_PATH

  if [ ! -f ${JAVAHOME}/${JAVADIR}/java ]; then
    JAVADIR=bin
  fi
fi

if [ "${INTERP}" = "linux-ix86" ]; then
  LD_LIBRARY_PATH=${JAVAHOME}/jre/bin/classic:${JAVAHOME}/jre/bin:${BIN_DIR}:${LD_LIBRARY_PATH}
  export LD_LIBRARY_PATH

  Version
  if [ $? -eq 1 ]
  then
    export LD_ASSUME_KERNEL=2.2.5
  fi
fi

if [ "${INTERP}" = "linux-s390" ]; then
  LD_LIBRARY_PATH=${JAVAHOME}/jre/bin/classic:${JAVAHOME}/jre/bin:${BIN_DIR}:${LD_LIBRARY_PATH}
  export LD_LIBRARY_PATH
fi

if [ "${INTERP}" = "aix4-r1" ]; then
  LIBPATH=${LIBPATH}:${JAVAHOME}/jre/bin/classic:${JAVAHOME}/jre/bin:${BIN_DIR}
  export LIBPATH
  # IY83993
  # Uncomment this line to always load tapmagent in extended shared memory
  # EXTSHM=ON
  if [ "$EXTSHM" = "ON" ] ; then
  	EXTRA_JVM_PARAMS="${EXTRA_JVM_PARAMS} -DEXTSHM=ON"
  fi
fi

if [ "${INTERP}" = "zos" ]; then
  LIBPATH=${LIBPATH}:${JAVAHOME}/bin:${JAVAHOME}/bin/classic:${BIN_DIR}
  LIBPATH=${LIBPATH}:${BIN_DIR}/USRLIB
  export LIBPATH
  JAVADIR=bin
  EXEC_CMD=nohup
  MASTDOUT=${CONFIG_DIR}/ma-stdout.log
  MASTDERR=${CONFIG_DIR}/ma-stderr.log
fi

if [ "${INTERP}" = "hpux11" ]; then
  SHLIB_PATH=${SHLIB_PATH}:${BIN_DIR}/USRLIB
  export SHLIB_PATH
  EXEC_CMD=nohup

  if [ ! -f ${JAVAHOME}/${JAVADIR}/java ]; then
    JAVADIR=bin
  fi
fi

if [ "${INTERP}" = "OS400" ]; then
  LIBSHAREDPATH=${BASEDIR}:${JAVAHOME}/BIN:${BIN_DIR}:${BIN_DIR}/USRLIB
  if [ -n "${LIBPATH}" ]; then
    export LIBPATH=${LIBSHAREDPATH}:${LIBPATH}
  else
    export LIBPATH=${LIBSHAREDPATH}
  fi
  export QIBM_MULTI_THREADED=Y
  liblist -a QTIVTMTP >/dev/null 2>/dev/null
  JAVADIR=bin
  EXTRA_JVM_PARAMS="${EXTRA_JVM_PARAMS} -Dos400.jdk13.jst.factories=true"
  EXTRA_JVM_PARAMS="${EXTRA_JVM_PARAMS} -Dos400.security.properties=/qibm/userdata/tivoli/tmtp/ma/config/java.security"
fi


#if it is restart then, wait until the MA actually shuts down
#so that it can be started back again. Wait for 180 sec
if [ "$1" = "restart" ]
then
    SHOW_PROGRESS=0
    WaitForProcessToStop
fi

# Check to see of agent is running
GetMARunningStatus

# If the agent is not running, remove the pid and shutdown flag files.
if [ $IS_RUNNING -eq 0 ]; then
  # Remove the eppid file
  rm -f ${PIDFILE} >/dev/null 2>/dev/null

  # Remove the Shutdown flag file
  RemoveSFF
fi

#The CLASSPATH must include the base and extensions jar-files, the path to the
#.properties files, the JLog package, and the JDK rt.jar file.
#Eg. export CLASSPATH=${LIB_DIR}/jmxc.jar:${LIB_DIR}/jmxx.jar:
##${JAVA_HOME}/jre/lib/rt.jar:${CLASSPATH}
# TMTP jars
CLASSPATH=${BASEDIR}/lib/local:\
${BASEDIR}/lib/local/patch.jar:\
${BASEDIR}/config:\
${BASEDIR}/lib:\
${BASEDIR}/lib/copyright.jar:\
${BASEDIR}/lib/base64_51.jar:\
${BASEDIR}/lib/logging.jar:\
${BASEDIR}/lib/ejflt.jar:\
${BASEDIR}/lib/tmtp_l10n.jar:\
${BASEDIR}/lib/core_util.jar:\
${BASEDIR}/lib/tmtp_nls.jar:\
${BASEDIR}/lib/launch.jar

# OEM jars
CLASSPATH=${CLASSPATH}:\
${BASEDIR}/lib/activation.jar:\
${BASEDIR}/lib/jffdc.jar:\
${BASEDIR}/lib/jflt.jar:\
${BASEDIR}/lib/jlog.jar:\
${BASEDIR}/lib/eppam.jar:\
${BASEDIR}/lib/ITLMToolkit.jar:\
${BASEDIR}/lib/jmxc.jar:\
${BASEDIR}/lib/jmxx.jar:\
${BASEDIR}/lib/log.jar:\
${BASEDIR}/lib/tmtpext.jar:\
${BASEDIR}/lib/xercesImpl.jar:\
${BASEDIR}/lib/xmlParserAPIs.jar:\
${BASEDIR}/lib/servlet-2_2.jar:\
${BASEDIR}/lib/mail.jar

export CLASSPATH

# Create the command line parameters we'll send to java
CLP=-Djava.class.path=${CLASSPATH}
CLP="${CLP} -Dtmtp.user.dir=${BASEDIR}"
if [ "${INTERP}" = "OS400" ]; then
  CLP="${CLP} -Dcom.ibm.tivoli.transperf.logging.baseDir=/qibm/userdata/tivoli/common"
else
  CLP="${CLP} -Dcom.ibm.tivoli.transperf.logging.baseDir=/var/ibm/tivoli/common"
fi
CLP="${CLP} com.ibm.tivoli.transperf.core.services.sm.Launch"

# cd to MA basedir
cd ${BASEDIR}

# IY64264 - Verify that the MA is not already running

  GetMARunningStatus

  PrepStdOut
  PrepStdErr

  if [ $IS_RUNNING -eq 1 ]; then
      echo TMTP MA process already running as PID: `cat ${PIDFILE}`
      # Launch the MA just to log message for already running
      ${EXEC_CMD} ${JAVAHOME}/${JAVADIR}/java ${EXTRA_JVM_PARAMS} ${CLP} 0 > ${MASTDOUT} 2>${MASTDERR}
  else
      ${EXEC_CMD} ${JAVAHOME}/${JAVADIR}/java ${EXTRA_JVM_PARAMS} ${CLP} 1 > ${MASTDOUT} 2>${MASTDERR} &
      JVMPID=$!
      # Write out the process id to file
      if [ "${JVMPID}" != "" ]; then
	if [ $SHOW_PROGRESS -eq 1 ]; then
          echo "Starting TMTP MA; process id ${JVMPID}"
	fi
      fi
      echo ${JVMPID} > ${PIDFILE}
  fi

  exit $IS_RUNNING

